<?php
namespace easynews_Framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class easynews_Blog extends Widget_Base {

	public function get_name() {
		return 'easynews_blog';
	}

	public function get_title() {
		return __( 'Blog', 'easynews-elements' );
	}

	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	public function get_categories() {
		return [ 'easynewstheme' ];
	}

	public function get_script_depends() {
		return [ 'script-elementor' ];
	}

	protected function _register_controls() {

		$args = array(
			'orderby' => 'name',
			'order' => 'ASC'
		);

		$categories=get_categories($args);
		$cate_array = array();
		$arrayCateAll = array( 'all' => 'All categories ' );
		if ($categories) {
			foreach ( $categories as $cate ) {
				$cate_array[$cate->cat_name] = $cate->slug;
			}
		} else {
			$cate_array["No content Category found"] = 0;
		}

		//SECTION CONTENT
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Content', 'easynews-elements' ),
			]
		);

		$this->add_control(
			'category',
			[
				'label' => __( 'Category', 'easynews-elements' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => array_merge($arrayCateAll,$cate_array),
			]
		);

		$this->add_control(
			'total_count',
			[
				'label' => __( 'Total Post', 'easynews-elements' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 3,
			]
		);

		$this->add_control(
			'columns',
			[
				'label' => __('Columns', 'easynews-elements'),
				'type' => Controls_Manager::SELECT,
				'default' => '3',
				'options' => [
					'1' => __('1', 'easynews-elements'),
					'2' => __('2', 'easynews-elements'),
					'3' => __('3', 'easynews-elements'),
					'4' => __('4', 'easynews-elements'),
				]
			]
		);

		$this->add_control(
			'order_by',
			[
				'label' => __('Order By', 'easynews-elements'),
				'type' => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'asc' => __('ASC', 'easynews-elements'),
					'desc' => __('DESC', 'easynews-elements'),
				]
			]
		);

		$this->add_control(
			'show_category',
			[
				'label' => __( 'Show Category', 'easynews-elements' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'easynews-elements' ),
				'label_off' => __( 'Hide', 'easynews-elements' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label' => __( 'Show Title', 'easynews-elements' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'easynews-elements' ),
				'label_off' => __( 'Hide', 'easynews-elements' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

	  $this->add_control(
			'show_excerpt',
			[
				'label' => __( 'Show Excerpt', 'easynews-elements' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'easynews-elements' ),
				'label_off' => __( 'Hide', 'easynews-elements' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_date',
			[
				'label' => __( 'Show Date', 'easynews-elements' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'easynews-elements' ),
				'label_off' => __( 'Hide', 'easynews-elements' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);


		$this->end_controls_section();
		//END SECTION CONTENT
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		
		$category = $settings['category'];
		$total_count = $settings['total_count'];
		$order = $settings['order_by'];

		$args = [];
		if ($category == 'all') {
			$args=[
				'post_type' => 'post',
				'posts_per_page' => $total_count,
				'order' => $order,
			];
		} else {
			$args=[
				'post_type' => 'post', 
				'category_name'=>$category,
				'posts_per_page' => $total_count,
				'order' => $order,
			];
		}

    $columns = $settings['columns'];
		switch ($columns) {
    case '1':
      $columns = 'one-fr';
      break;
    case '2':
      $columns = 'two-fr';
      break;
    case '3':
      $columns = 'three-fr';
      break;
    case '4':
      $columns = 'four-fr';
      break;
    }

		$blog = new \WP_Query($args);

		?>
		<div class="easynews-blog blog-posts <?php echo $columns; ?>">

			<?php
			if($blog->have_posts()) : while($blog->have_posts()) : $blog->the_post();
				$thumbnail_url = wp_get_attachment_image_url(get_post_thumbnail_id() , 'framek-big-thumb' );
				?>

				<div class="post-item">
					<div class="image-part">
						<a href="<?php echo esc_attr(get_the_permalink()); ?>">
							<img src="<?php echo esc_attr($thumbnail_url) ?>" alt="<?php echo esc_attr(get_the_title()); ?>">
						</a>
					</div>
					<div class="content-part">
						<?php if($settings['show_category']) : ?>
							<div class="post-cats">
								<a href="<?php echo esc_attr(get_the_permalink()); ?>"><?php the_category(' <span>/</span> '); ?></a>
							</div>
						<?php endif ?>
						<?php if($settings['show_title']) : ?>
							<h3 class="post-title">
								<a href="<?php echo esc_attr(get_the_permalink()); ?>"><?php echo esc_html(get_the_title()); ?></a>
							</h3>
						<?php endif ?>
						<?php if($settings['show_excerpt']) : ?>
						<div class="post-excerpt">	
			        <?php echo easynews_excerpt(20); ?>
		        </div>
		        <?php endif ?>
						<?php if ($settings['show_date']) : ?>
							<div class="post-meta">
								<span class="post-date"><?php echo esc_html(the_time(get_option('date_format'))); ?></span>
							</div>
						<?php endif ?>
				  </div>
        </div>
				<?php
			endwhile; endif; wp_reset_postdata();
			?>

		</div>
		<?php
	}
}
