<?php

namespace easynews_Framework\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class easynews_Products extends Widget_Base {

  public function get_name() {
    return 'easynews_products';
  }

  public function get_title() {
    return esc_html__( 'easynews Products', 'easynews-elements' );
  }

  public function get_icon() {
    return 'fa fa-shopping-bag';
  }

  public function get_categories() {
    return [ 'easynewstheme' ];
  }

  public function get_script_depends() {
    return [ 'script-elementor' ];
  }

  protected function _register_controls() {

      
    //SECTION CONTENT
    $this->start_controls_section(
      'content_section',
      [
        'label' => esc_html__( 'Content', 'capie' ),
        'tab' => Controls_Manager::TAB_CONTENT,
      ]
    );
      
      $this->add_control(
        'title', 
        [
          'label' => esc_html__( 'Widget Title', 'capie' ),
          'type' => Controls_Manager::TEXT
        ]
      );

      $this->add_control(
        'subtitle', 
        [
          'label' => esc_html__( 'Widget Sub Title', 'capie' ),
          'type' => Controls_Manager::TEXT
        ]
      );

      $this->add_control(
        'type',
        [
          'label' => esc_html__( 'Get Products By', 'capie' ),
          'type' => Controls_Manager::SELECT,
          'options' => array(
              'recent_product' => esc_html__('Recent Products', 'capie' ),
              'best_selling' => esc_html__('Best Selling', 'capie' ),
              'featured_product' => esc_html__('Featured Products', 'capie' ),
              'top_rate' => esc_html__('Top Rate', 'capie' ),
              'on_sale' => esc_html__('On Sale', 'capie' ),
              'recent_review' => esc_html__('Recent Review', 'capie' ),
          ),
          'default' => 'recent_product'
        ]
      );

        $this->add_control(
            'slugs',
            [
                'label' => esc_html__( 'Categories Slug', 'capie' ),
                'type' => Controls_Manager::TEXTAREA,
                'rows' => 2,
                'default' => '',
                'placeholder' => esc_html__( 'Enter id spearate by comma(,)', 'capie' ),
            ]
        );

        $this->add_control(
            'link',
            [
                'label'       => esc_html__( 'URL', 'capie' ),
                'type'        => Controls_Manager::TEXT,
                'input_type'  => 'url',
                'placeholder' => esc_html__( 'Enter your url button link here', 'capie' ),
            ]
        );

        $this->add_control(
            'btn_text',
            [
                'label'       => esc_html__( 'Button Text', 'capie' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter your button text here', 'capie' ),
            ]
        );
        
        $this->add_control(
            'limit',
            [
                'label' => esc_html__( 'Limit', 'capie' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'number',
                'placeholder' => esc_html__( 'Enter number products to display', 'capie' ),
                'default' => 4
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label' => esc_html__( 'Layout', 'capie' ),
                'type' => Controls_Manager::SELECT,
                'options' => array(
                    'grid' => esc_html__('Grid', 'capie'),
                    'carousel' => esc_html__('Carousel', 'capie'),                    
                    'list' => esc_html__('List', 'capie'),
                    'special' => esc_html__('Special', 'capie'),
                ),
                'default' => 'grid'
            ]
        );

        $this->add_control(
            'columns',
            [
                'label' => esc_html__( 'Columns', 'capie' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'number',
                'placeholder' => esc_html__( 'Enter your column number here', 'capie' ),
                'default' => 4
            ]
        );

        $this->add_control(
            'rows',
            [
                'label' => esc_html__( 'Rows', 'capie' ),
                'type' => Controls_Manager::TEXT,
                'input_type' => 'number',
                'placeholder' => esc_html__( 'Enter your rows number here', 'capie' ),
                'default' => 1,
                'condition' => [
                    'layout_type' => 'carousel',
                ],
            ]
        );

        $this->end_controls_section();
        //END SECTION CONTENT
}

  protected function render() {
        $settings = $this->get_settings();

        extract( $settings );

        ?>
        <div class="widget widget-products <?php echo esc_attr($layout_type); ?>">            
            <?php if ( !empty($title) ): ?>
                <header class="widget-heading-container">
                    <h3 class="widget-title">
                        <span><?php echo esc_attr( $title ); ?></span>
                    </h3>
                </header>
            <?php endif; ?>
            <?php if ( !empty($subtitle) ): ?>
                <h5 class="widget-subtitle">
                    <span><?php echo esc_attr( $subtitle ); ?></span>
                </h5>
            <?php endif; ?>          
            <div class="woocommerce elementor-products">                
                <?php
                    $slugs = !empty($slugs) ? array_map('trim', explode(',', $slugs)) : array();
                    $type = isset($type) ? $type : 'recent_product';
                    $args = array(
                        'categories' => $slugs,
                        'product_type' => $type,
                        'post_per_page' => $limit,
                    );
                    
                    $loop = easynews_get_products( $args );
                
                    wc_get_template( 'layout-products/'.$layout_type.'.php' , array(
                        'loop' => $loop,
                        'columns' => $columns,
                        'rows' => $rows,
                        'product_item' => 'inner',
                    ) );
                ?>
            </div>            
            <?php if ( !empty($link) && !empty($btn_text) ) { ?>
                <div class="widget-link">
                    <a href="<?php echo esc_url($link); ?>" class="btn btn-outline-primary" target="_blank">
                        <span><?php echo wp_kses_post($btn_text); ?></span>
                    </a>
                </div>        
            <?php } ?>            
        </div>
        <?php
    }
}