<?php
// don't load directly
if (!defined('ABSPATH')) die('-1');

class musicnight_extend_vc_addon_album_playlist {
    function __construct() {
        // We safely integrate with VC with this hook
        add_action( 'init', array( $this, 'musicnight_vc_notice' ) );
 
        // Use this when creating a shortcode addon
        add_shortcode( 'album_playlist_item', array( $this, 'musicnight_print_element' ) );
        // Register CSS and JS
        add_action( 'wp_enqueue_scripts', array( $this, 'musicnight_load_style' ) );
    }
 
    public function musicnight_vc_notice() {
        // Check if Visual Composer is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Visual Compser is required
            // add_action('admin_notices', array( $this, 'musicnight_print_vc_notice' ));
            return;
        }
 
        /*
        Add your Visual Composer logic here.
        Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.
        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
        vc_map( array(
            "name" => __("Album Playlist", 'music-night'),
            //"description" => __("Fetch all the album posts from by category or tags.", 'music-night'),
			"description" => __("KodeForest", 'music-night'),
            "base" => "album_playlist_item",
            "class" => "",
            "controls" => "full",
            "icon" => "call-to-action", // New param added
            "category" => __('music-night', 'music-night'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            'admin_enqueue_css' => array(plugins_url('assets/vc_style_extend.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Item Id", 'music-night'),
					"param_name" => "element_item_id",
					"value" => __(" ", 'music-night'),
					"description" => __("Please add item id here.", 'music-night')
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Item Class", 'music-night'),
					"param_name" => "element_item_class",
					"value" => __(" ", 'music-night'),
					"description" => __("Please add item class here.", 'music-night')
				),
				array(
					'type' => 'checkbox',
					'heading' => __( 'Select Category', 'music-night' ),
					'param_name' => 'category',
					'value' => musicnight_get_term_list_emptyfirst('album_category'),
					'description' => __( 'Select Category.', 'music-night' )
				),
				array(
					'type' => 'checkbox',
					'heading' => __( 'Select Tag', 'music-night' ),
					'param_name' => 'tag',
					'value' => musicnight_get_term_list_emptyfirst('album_tag'),
					'description' => __( 'Select Tag.', 'music-night' )
				),
				array(
					"type" => "colorpicker",
					"class" => "",
					"heading" => __("Background Color", 'music-night'),
					"param_name" => "background_color",
					"value" => __("#ffffff", 'music-night'),
					"description" => __("You can add playlist background color.", 'music-night')
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Player Type', 'music-night' ),
					'param_name' => 'player_type',
					'value' => array(
					    __( ' ', 'music-night' ) => 'no-category',
						__( 'Horizontal', 'music-night' ) => 'horizontal',
						__( 'Full Player Box', 'music-night' ) => 'full-player',
					),
					'description' => __( 'Select Style.', 'music-night' )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Player Position', 'music-night' ),
					'param_name' => 'position',
					'value' => array(
					    __( ' ', 'music-night' ) => 'no-category',
						__( 'Fixed At Top', 'music-night' ) => 'fixed-t',
						__( 'Fixed At Bottom', 'music-night' ) => 'fixed-b',
						__( 'Float From Left', 'music-night' ) => 'fixed-bl',
						__( 'Static', 'music-night' ) => 'static',
					),
					'description' => __( 'Select Style.', 'music-night' )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Order By', 'music-night' ),
					'param_name' => 'orderby',
					'value' => array(
					    __( ' ', 'music-night' ) => 'no-category',
						__( 'Publish Date', 'music-night' ) => 'date',
						__( 'Title', 'music-night' ) => 'title',
						__( 'Random', 'music-night' ) => 'rand',
					),				
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Order', 'music-night' ),
					'param_name' => 'order',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Descending Order', 'music-night' ) => 'desc',
						__( 'Ascending Order', 'music-night' ) => 'asc'						
					),				
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Margin Bottom", 'music-night'),
					"param_name" => "margin_bottom",
					"value" => __(" ", 'music-night'),
					"description" => __("margin from bottom without pixel for example : 10.", 'music-night')
				),
            )
        ) );
    }
	
	
    
    /*
    Shortcode logic how it should be rendered
    */
    public function musicnight_print_element( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'element_item_id' => '',
			'element_item_class' => '',
			'category' => '',
			'tag' => '',
			'background_color' => '',
			'player_type' => '',
			'position' => '',
			'orderby' => '',
			'order' => '',
			'margin_bottom' => '',
		), $atts ) );

		$content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content		
		$settings = array();
		$settings['element-item-id'] = $element_item_id;
		$settings['element-item-class'] = $element_item_class;
		$settings['category'] = $category;
		$settings['tag'] = $tag;
		$settings['player-type'] = $player_type;
		$settings['background-color'] = $background_color;
		$settings['position'] = $position;
		$settings['orderby'] = $orderby;		
		$settings['order'] = $order;
		$settings['margin-bottom'] = $margin_bottom;
		
		$output = '<div class="row">'.musicnight_get_album_playlist($settings).'</div>';
		return $output;
    }
    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    public function musicnight_load_style() {
		
    }
    /*
    Show notice if your plugin is activated but Visual Composer is not
    */
    public function musicnight_print_vc_notice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'music-night'), $plugin_data['Name']).'</p>
        </div>';
    }
}
// Finally initialize code
new musicnight_extend_vc_addon_album_playlist();