<?php
// don't load directly
if (!defined('ABSPATH')) die('-1');

class musicnight_extend_vc_addon_services {
    function __construct() {
        // We safely integrate with VC with this hook
        add_action( 'init', array( $this, 'musicnight_vc_notice' ) );
 
        // Use this when creating a shortcode addon
        add_shortcode( 'service_item', array( $this, 'musicnight_print_element' ) );
        // Register CSS and JS
        add_action( 'wp_enqueue_scripts', array( $this, 'musicnight_load_style' ) );
    }
 
    public function musicnight_vc_notice() {
        // Check if Visual Composer is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Visual Compser is required
           // add_action('admin_notices', array( $this, 'musicnight_print_vc_notice' ));
            return;
        }
 
        /*
        Add your Visual Composer logic here.
        Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.
        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
        vc_map( array(
            "name" => __("Kode Services Item", 'music-night'),
            //"description" => __("Fetch all the service posts from by category or tags.", 'music-night'),
			"description" => __("Fetch all the services", 'music-night'),
            "base" => "service_item",
            "class" => "",
            "controls" => "full",
            "icon" => '', // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('music-night', 'music-night'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
				array(
					'type' => 'dropdown',
					'heading' => __( 'Select Category', 'music-night' ),
					'param_name' => 'service_category',
					'value' => musicnight_get_term_list_emptyfirst('service_category'),
					'description' => __( 'Select Category.', 'music-night' )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Select Tag', 'music-night' ),
					'param_name' => 'service_tag',
					'value' => musicnight_get_term_list_emptyfirst('service_tag'),
					'description' => __( 'Select Tag.', 'music-night' )
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Title Num Fetch", 'music-night'),
					"param_name" => "title_num_fetch",					
					"description" => __("Specify the number you want to pull out the title character.", 'music-night')
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Select Style', 'music-night' ),
					'param_name' => 'service_style',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Style 1', 'music-night' ) => 'type-1',
						__( 'Style 2', 'music-night' ) => 'type-2',
						__( 'Style 3', 'music-night' ) => 'type-3',
					),
					'description' => __( 'Select Style.', 'music-night' )
				),
				array(
					 'type' => 'dropdown',
					 'heading' => __( 'Select Thumbnail Size', 'music-night' ),
					 'param_name' => 'thumbnail_size',
					 'value' => musicnight_get_thumbnail_list_vc(),
					 'description' => __( 'Select Image Size.', 'music-night' )
				 ),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Service Padding', 'music-night' ),
					'param_name' => 'service_padding',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Without Padding', 'music-night' ) => 'without-padding',
						__( 'With Padding', 'music-night' ) => 'with-padding',
					),
					'description' => __( 'Select the services padding Style.', 'music-night' )
				), 
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Num Fetch", 'music-night'),
					"param_name" => "num_fetch",
					"value" => __("5", 'music-night'),
					"description" => __("Specify the number of services you want to pull out.", 'music-night')
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Num Excerpt", 'music-night'),
					"param_name" => "num_excerpt",
					"value" => __("20", 'music-night'),
					"description" => __("Specify the number of services description you want to pull out.", 'music-night')
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Order By', 'music-night' ),
					'param_name' => 'orderby',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Publish Date', 'music-night' ) => 'date',
						__( 'Title', 'music-night' ) => 'title',
						__( 'Random', 'music-night' ) => 'rand',
					),				
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Order', 'music-night' ),
					'param_name' => 'order',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Descending Order', 'music-night' ) => 'desc',
						__( 'Ascending Order', 'music-night' ) => 'asc'						
					),				
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Pagination', 'music-night' ),
					'param_name' => 'pagination',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Enable', 'music-night' ) => 'enable',
						__( 'Disable', 'music-night' ) => 'disable'						
					),				
				),
            )
        ) );
    }
	
	
    
    /*
    Shortcode logic how it should be rendered
    */
    public function musicnight_print_element( $atts, $content = null ) {
		extract( shortcode_atts( array(        
			'service_category' => '',
			'service_tag' => '',
			'service_style' => '',
			'num_fetch' => '',
			'num_excerpt' => '',
			'orderby' => '',
			'order' => '',
			'thumbnail_size' => '',
			'service_padding' => '',
			'title_num_fetch' => '',
			'pagination' => ''
		), $atts ) );

		$content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content		
		$settings['category'] = $service_category;
		$settings['tag'] = $service_tag;
		$settings['service-style'] = $service_style;
		$settings['num-fetch'] = $num_fetch;
		$settings['num-excerpt'] = $num_excerpt;
		$settings['orderby'] = $orderby;
		$settings['thumbnail-size'] = $thumbnail_size;
		$settings['order'] = $order;
		$settings['service-padding'] = $service_padding;
		$settings['title-num-fetch'] = $title_num_fetch;
		$settings['pagination'] = $pagination;
		
		$output = '<div class="row">'.musicnight_get_service_item($settings).'</div>';
		return $output;
    }
    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    //public function musicnight_load_style() {
      //wp_register_style( 'vc_extend_style', plugins_url('assets/vc_extend.css', __FILE__) );
      //wp_enqueue_style( 'vc_extend_style' );
      // If you need any javascript files on front end, here is how you can load them.
      //wp_enqueue_script( 'vc_extend_js', plugins_url('assets/vc_extend.js', __FILE__), array('jquery') );
    //}
    /*
    Show notice if your plugin is activated but Visual Composer is not
    */
    public function musicnight_print_vc_notice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'music-night'), $plugin_data['Name']).'</p>
        </div>';
    }
}
// Finally initialize code
new musicnight_extend_vc_addon_services();