<?php
/**
 * Plugin Name: Kodeforest Contact Us Widget
 * Plugin URI: http://kodeforest.com/
 * Description: A widget that show Have a Contact Us Box.
 * Version: 1.0
 * Author: Kodeforest
 * Author URI: http://www.kodeforest.com
 *
 */

add_action( 'widgets_init', 'musicnight_contact_us_widget' );
if( !function_exists('musicnight_contact_us_widget') ){
	function musicnight_contact_us_widget() {
		register_widget( 'Kodeforest_Contact' );
	}
}

if( !class_exists('Kodeforest_Contact') ){
	class Kodeforest_Contact extends WP_Widget{

		// Initialize the widget
		function __construct() {
			parent::__construct(
				'musicnight_contact_us_widget', 
				esc_html__('Kodeforest Contact Widget','music-night'), 
				array('description' => esc_html__('A widget that show Have A Contact information.', 'music-night')));  
		}

		// Output of the widget
		function widget( $args, $instance ) {
			global $musicnight_theme_option;	
				
			$title = apply_filters( 'widget_title', $instance['title'] );
			$widget_desc = $instance['widget_desc'];			
			$widget_class = $instance['widget_class'];			
			
			$phone_number = $instance['phone_number'];
			$email_id = $instance['email_id'];
			$location = $instance['location'];

			// Opening of widget
			echo $args['before_widget'];
			
			
			?>
			
			<div class="widget-contact social-contact <?php echo esc_attr($widget_class);?>">
				<h4 class="widget-title2"><?php echo esc_attr($title)?></h4>
				<?php if(isset($widget_desc) && $widget_desc <> ''){ ?>
					<p><?php echo esc_attr($widget_desc)?></p>
				<?php }?>
				<ul class="kf_contact_meta">
					<?php if(isset($phone_number) && $phone_number <> ''){ ?>
						<li>
							<span class="fa fa-phone"></span>
							<p><?php echo esc_attr($phone_number);?></p>
						</li>
					<?php }?>
					<?php if(isset($email_id) && $email_id <> ''){ ?>
						<li>
							<span class="fa fa-envelope"></span>
							<p><?php echo esc_attr($email_id);?></p>
						</li>
					<?php }?>
					<?php if(isset($location) && $location <> ''){ ?>
						<li>
							<span class="fa fa-map-marker"></span>
							<p><?php echo esc_attr($location);?></p>
						</li>
					<?php }?>
				</ul>
			</div>
			<?php
			// Closing of widget
			echo $args['after_widget'];	
		}

		// Widget Form
		function form( $instance ) {
			$title = isset($instance['title'])? $instance['title']: '';
			$widget_desc = isset($instance['widget_desc'])? $instance['widget_desc']: '';
			$widget_class = isset($instance['widget_class'])? $instance['widget_class']: '';
			$phone_number = isset($instance['phone_number'])? $instance['phone_number']: '';
			$email_id = isset($instance['email_id'])? $instance['email_id']: '';
			$location = isset($instance['location'])? $instance['location']: '';
			
			?>
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('widget_class')); ?>"><?php esc_html_e('Widget Class :', 'music-night'); ?></label> 
				<input class="widefat" id="<?php echo esc_attr($this->get_field_id('widget_class')); ?>" name="<?php echo esc_attr($this->get_field_name('widget_class')); ?>" type="text" value="<?php echo esc_attr($widget_class); ?>" />
			</p>
			<!-- Text Input -->
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title :', 'music-night'); ?></label> 
				<input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
			</p>
			<!-- Text Input -->
						
			<!-- Widget Icon --> 
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('widget_desc')); ?>"><?php esc_html_e('Widget Description :', 'music-night'); ?></label>
				<input class="widefat" id="<?php echo esc_attr($this->get_field_id('widget_desc')); ?>" name="<?php echo esc_attr($this->get_field_name('widget_desc')); ?>" type="text" value="<?php echo esc_attr($widget_desc); ?>" />
			</p>
			<!-- Widget Link --> 
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('phone_number')); ?>"><?php esc_html_e('Phone Number :', 'music-night'); ?></label>
				<input class="widefat" id="<?php echo esc_attr($this->get_field_id('phone_number')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_number')); ?>" type="text" value="<?php echo esc_attr($phone_number); ?>" />
			</p>
			<!-- Widget Link --> 
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('email_id')); ?>"><?php esc_html_e('Email ID :', 'music-night'); ?></label>
				<input class="widefat" id="<?php echo esc_attr($this->get_field_id('email_id')); ?>" name="<?php echo esc_attr($this->get_field_name('email_id')); ?>" type="text" value="<?php echo esc_attr($email_id); ?>" />
			</p>
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('location')); ?>"><?php esc_html_e('Location :', 'music-night'); ?></label>
				<input class="widefat" id="<?php echo esc_attr($this->get_field_id('location')); ?>" name="<?php echo esc_attr($this->get_field_name('location')); ?>" type="text" value="<?php echo esc_attr($location); ?>" />
			</p>

		<?php
		}
		
		// Update the widget
		function update( $new_instance, $old_instance ) {
			$instance = array();
			$instance['title'] = (empty($new_instance['title']))? '': strip_tags($new_instance['title']);
			$instance['widget_desc'] = (empty($new_instance['widget_desc']))? '': strip_tags($new_instance['widget_desc']);				
			$instance['widget_class'] = (empty($new_instance['widget_class']))? '': strip_tags($new_instance['widget_class']);				
			$instance['phone_number'] = (empty($new_instance['phone_number']))? '': strip_tags($new_instance['phone_number']);
			$instance['email_id'] = (empty($new_instance['email_id']))? '': strip_tags($new_instance['email_id']);
			$instance['location'] = (empty($new_instance['location']))? '': strip_tags($new_instance['location']);
			
			return $instance;
		}	
	}
}
?>