<?php
/**
 * Plugin Name: Latest Events Widget
 * Plugin URI: http://kodeforest.com/
 * Description: A widget that show Latest Events.
 * Version: 1.0
 * Author: Kodeforest
 * Author URI: http://www.kodeforest.com
 *
 */

add_action( 'widgets_init', 'musicnight_upcoming_events_widget' );
if( !function_exists('musicnight_upcoming_events_widget') ){
	function musicnight_upcoming_events_widget() {
		register_widget( 'Kodeforest_Upcoming_Events' );
	}
}

if( !class_exists('Kodeforest_Upcoming_Events') ){
	class Kodeforest_Upcoming_Events extends WP_Widget{

		// Initialize the widget
		function __construct() {
			parent::__construct(
				'musicnight_upcoming_events_widget', 
				esc_attr__('Kodeforest Upcoming Events Widget','music-night'), 
				array('description' => esc_attr__('A widget that shows Upcoming Events.', 'music-night')));  
		}

		// Output of the widget
		function widget( $args, $instance ) {
			global $musicnight_theme_option;	
				
			$title = apply_filters( 'widget_title', $instance['title'] );
			$category = $instance['category'];
			$num_fetch = $instance['num_fetch'];			
			
			// Opening of widget
			echo $args['before_widget'];
			
				echo '
				<div class="latest_album_list">';
					// Open of title tag
					if( !empty($title) ){ 
						echo $args['before_title'] . esc_attr($title) . $args['after_title']; 
					}
					echo '<div class="latest_album_event"><ul>';
					$evn = '';
					$order = 'DESC';
					$limit = 10;//Default limit
					$offset = '';		
					$rowno = 0;
					$event_count = 0;
					$EM_Events = EM_Events::get( array('category'=>$category, 'group'=>'this','scope'=>'all', 'limit' => $num_fetch, 'order' => 'desc') );
					$events_count = count ( $EM_Events );	
					foreach($EM_Events as $event){
						$event_post_data = musicnight_decode_stopbackslashes(get_post_meta($event->post_id, 'post-option', true ));
						if( !empty($event_post_data)){
							if(!is_array($event_post_data)){
								$event_post_data = json_decode( $event_post_data, true );				
							}
						}					
						if($event->event_all_day <> 1){
							$start_time = $event->start_time;
							$end_time = $event->end_time;
						}else{

							$start_time = '12:00';
							$end_time = '12:00';
							
						}
						$event_year = date('Y',$event->start);
						$event_month = date('M',$event->start);
						$event_day = date('d',$event->start);
						// print_r($event->start_time);
						$event_start_time = date("G : i a", strtotime($start_time));
						$event_end_time = date("G : i a", strtotime($end_time));
						echo '
						<li>
							<div class="latest_album_event_list">
								<div class="latest_event_date">
									<span>'.esc_attr($event_day).'</span>
									<h4>'.esc_attr($event_month).'</h4>
									<span>'.esc_attr($event_year).'</span>
								</div>
								<div class="latest_album_event_text">
									<h5>'.esc_attr(get_the_title()).'</h5>
									<a href="'.esc_url(get_permalink()).'"><i class="fa fa-map-marker"></i> club galaxy center </a>
								</div>
								<a class="cart_btn pink_dark" href="'.esc_url(get_permalink()).'"><i class="fa icon-shopping-cart"></i></a>
							</div>
						</li>';
						$event_count++;
					}
					echo '
				</ul>
				</div>
			</div>';
			echo '
			<!--Widget Next Match End-->';
					
			// Closing of widget
			echo $args['after_widget'];	
			
		}

		// Widget Form
		function form( $instance ) {
			$title = isset($instance['title'])? $instance['title']: '';
			$category = isset($instance['category'])? $instance['category']: '';
			$num_fetch = isset($instance['num_fetch'])? $instance['num_fetch']: '';?>

			<!-- Text Input -->
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_attr_e('Title :', 'music-night'); ?></label> 
				<input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
			</p>			
			<!-- Post Category -->
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('category')); ?>"><?php esc_html_e('Category :', 'music-night'); ?></label>		
				<select class="widefat" name="<?php echo esc_attr($this->get_field_name('category')); ?>" id="<?php echo esc_attr($this->get_field_id('category')); ?>">
				<option value="" <?php if(empty($category)) echo ' selected '; ?>><?php esc_html_e('All', 'music-night') ?></option>
				<?php 	
				$category_list = musicnight_get_term_list('event-categories'); 
				foreach($category_list as $cat_slug => $cat_name){ ?>
					<option value="<?php echo esc_attr($cat_slug); ?>" <?php if ($category == $cat_slug) echo ' selected '; ?>><?php echo esc_attr($cat_name); ?></option>				
				<?php } ?>	
				</select> 
			</p>
			<!-- Post Layout -->
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('num_fetch')); ?>"><?php esc_attr_e('Num Fetch :', 'music-night'); ?></label>
				<input class="widefat" id="<?php echo esc_attr($this->get_field_id('num_fetch')); ?>" name="<?php echo esc_attr($this->get_field_name('num_fetch')); ?>" type="text" value="<?php echo esc_attr($num_fetch); ?>" />
			</p>
			
		<?php
		}
		
		// Update the widget
		function update( $new_instance, $old_instance ) {
			$instance = array();
			$instance['title'] = (empty($new_instance['title']))? '': strip_tags($new_instance['title']);
			$instance['category'] = (empty($new_instance['category']))? '': strip_tags($new_instance['category']);			
			$instance['num_fetch'] = (empty($new_instance['num_fetch']))? '': strip_tags($new_instance['num_fetch']);
			

			return $instance;
		}	
	}
}
?>