<?php
// don't load directly
if (!defined('ABSPATH')) die('-1');

class musicnight_extend_vc_addon_post_slider {
    function __construct() {
        // We safely integrate with VC with this hook
        add_action( 'init', array( $this, 'musicnight_vc_notice' ) );
 
        // Use this when creating a shortcode addon
        add_shortcode( 'team_item', array( $this, 'musicnight_print_element' ) );
        // Register CSS and JS
        add_action( 'wp_enqueue_scripts', array( $this, 'musicnight_load_style' ) );
    }
 
    public function musicnight_vc_notice() {
        // Check if Visual Composer is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Visual Compser is required
            add_action('admin_notices', array( $this, 'musicnight_print_vc_notice' ));
            return;
        }
 
        /*
        Add your Visual Composer logic here.
        Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.
        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
        vc_map(array(
            "name" => __("Post Slider", 'music-night'),
            //"description" => __("Fetch all the team posts from by category or tags.", 'music-night'),
			"description" => __("KodeForest", 'music-night'),
            "base" => "post_slider",
            "class" => "",
            "controls" => "full",
            "icon" => '', // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Content', 'music-night'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Element Item ID", 'music-night'),
					"param_name" => "element_item_id",
					"value" => __("", 'music-night'),
					"description" => __("Please add the custom id for this element from here.", 'music-night')
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Element Item Class", 'music-night'),
					"param_name" => "element_item_class",
					"value" => __("", 'music-night'),
					"description" => __("Please add the custom Class for this element from here.", 'music-night')
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Category', 'music-night' ),
					'param_name' => 'category',
					'value' => musicnight_get_term_list_emptyfirst('video_category'),
					'description' => __( 'Select categories to fetch its posts.', 'music-night' )
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Num Excerpt", 'music-night'),
					"param_name" => "num_excerpt",
					"value" => __("25", 'music-night'),
					'description' => __( 'This is a number of word (decided by spaces) that you want to show on the post excerpt.', 'music-night' )
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Num Fetch", 'music-night'),
					"param_name" => "num_fetch",
					"value" => __("8", 'music-night'),
					'description' => __( 'Specify the number of posts you want to pull out.', 'music-night' )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Thumbnail Size', 'music-night' ),
					'param_name' => 'thumbnail_size',
					'value' => musicnight_get_term_list_emptyfirst(''),
					'description' => __( 'Select thumbnail size of this element from here.', 'music-night' )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Style', 'music-night' ),
					'param_name' => 'style',
					'value' => array(
						__( 'No Excerpt', 'no-excerpt' ) => 'music-night',
						__( 'With Excerpt', 'with-excerpt' ) => 'music-night'						
					),				
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Caption Style', 'music-night' ),
					'param_name' => 'caption_style',
					'value' => array(
						__( 'Bottom Caption', 'post-bottom post-slider' ) => 'music-night',
						__( 'Right Caption', 'post-right post-slider' ) => 'music-night'
						__( 'Left Caption', 'post-left post-slider' ) => 'music-night'
					),
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Order By', 'music-night' ),
					'param_name' => 'orderby',
					'value' => array(
						__( 'Publish Date', 'date' ) => 'music-night',
						__( 'Title', 'title' ) => 'music-night'
						__( 'Random', 'rand' ) => 'music-night'
					),				
				),					
				array(
					'type' => 'dropdown',
					'heading' => __( 'Order', 'music-night' ),
					'param_name' => 'order',
					'value' => array(
						__( 'Descending Order', 'desc' ) => 'music-night',
						__( 'Ascending Order', 'asc' ) => 'music-night'
					),				
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Margin Bottom", 'music-night'),
					"param_name" => "margin_bottom",
					"value" => __("Spaces after ending of this item", 'music-night'),
					'description' => __( 'Spaces after ending of this item', 'music-night' )
				),
			)
        ));
    }
	
	
    
    /*
    Shortcode logic how it should be rendered
    */
    public function musicnight_print_element( $atts, $content = null ) {
		extract( shortcode_atts( array(        
			'woo_category' => '',
			'woo_tag' => '',
			'woo_style' => '',
			'num_fetch' => '',
			'num_excerpt' => '',
			'orderby' => '',
			'order' => '',
			'pagination' => ''
		), $atts ) );

		$content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content		
		$settings['category'] = $woo_category;
		$settings['tag'] = $woo_tag;
		$settings['woo-column-size'] = $woo_style;
		$settings['num-fetch'] = $num_fetch;
		$settings['num-excerpt'] = $num_excerpt;
		$settings['orderby'] = $orderby;		
		$settings['order'] = $order;
		$settings['pagination'] = $pagination;
		$output = '<div class="row">'.musicnight_get_woo_item($settings).'</div>';
		return $output;
    }
    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    public function musicnight_load_style() {
      // wp_register_style( 'vc_extend_style', plugins_url('assets/vc_extend.css', __FILE__) );
      // wp_enqueue_style( 'vc_extend_style' );
      // If you need any javascript files on front end, here is how you can load them.
      //wp_enqueue_script( 'vc_extend_js', plugins_url('assets/vc_extend.js', __FILE__), array('jquery') );
    }
    /*
    Show notice if your plugin is activated but Visual Composer is not
    */
    public function musicnight_print_vc_notice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'music-night'), $plugin_data['Name']).'</p>
        </div>';
    }
}
// Finally initialize code
new musicnight_extend_vc_addon_post_slider();