<?php
// don't load directly
if (!defined('ABSPATH')) die('-1');

class musicnight_extend_vc_addon_woo {
    function __construct() {
        // We safely integrate with VC with this hook
        add_action( 'init', array( $this, 'musicnight_vc_notice' ) );
 
        // Use this when creating a shortcode addon
        add_shortcode( 'team_item', array( $this, 'musicnight_print_element' ) );
        // Register CSS and JS
        add_action( 'wp_enqueue_scripts', array( $this, 'musicnight_load_style' ) );
    }
 
    public function musicnight_vc_notice() {
        // Check if Visual Composer is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Visual Compser is required
            add_action('admin_notices', array( $this, 'musicnight_print_vc_notice' ));
            return;
        }
 
        /*
        Add your Visual Composer logic here.
        Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.
        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
        vc_map(array(
            "name" => __("Woo Item", 'music-night'),
            //"description" => __("Fetch all the team posts from by category or tags.", 'music-night'),
			"description" => __("KodeForest", 'music-night'),
            "base" => "woo_item",
            "class" => "",
            "controls" => "full",
            "icon" => '', // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => __('Content', 'music-night'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            //'admin_enqueue_css' => array(plugins_url('assets/vc_extend_admin.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
				array(
					'type' => 'dropdown',
					'heading' => __( 'Select Category', 'music-night' ),
					'param_name' => 'woo_category',
					'value' => musicnight_get_term_list_emptyfirst('product_cat'),
					'description' => __( 'Select Category.', 'music-night' )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Select Tag', 'music-night' ),
					'param_name' => 'woo_tag',
					'value' => musicnight_get_term_list_emptyfirst('product_tag'),
					'description' => __( 'Select Tag.', 'music-night' )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Select Style', 'music-night' ),
					'param_name' => 'woo_style',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__('2 Column Grid', 'music-night') => '2',
						__('3 Column Grid', 'music-night') => '3',
						__('4 Column Grid', 'music-night') => '4'
					),
					'description' => __( 'Select Style.', 'music-night' )
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Num Fetch", 'music-night'),
					"param_name" => "num_fetch",
					"value" => __("5", 'music-night'),
					"description" => __("Specify the number of woo you want to pull out.", 'music-night')
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Num Excerpt", 'music-night'),
					"param_name" => "num_excerpt",
					"value" => __("20", 'music-night'),
					"description" => __("Specify the number of woo description you want to pull out.", 'music-night')
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Order By', 'music-night' ),
					'param_name' => 'orderby',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Publish Date', 'music-night' ) => 'date',
						__( 'Title', 'music-night' ) => 'title',
						__( 'Random', 'music-night' ) => 'rand',
					),				
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Order', 'music-night' ),
					'param_name' => 'order',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Descending Order', 'music-night' ) => 'desc',
						__( 'Ascending Order', 'music-night' ) => 'asc'						
					),				
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Pagination', 'music-night' ),
					'param_name' => 'pagination',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Enable', 'music-night' ) => 'enable',
						__( 'Disable', 'music-night' ) => 'disable'						
					),				
				),
            )
        ));
    }
	
	
    
    /*
    Shortcode logic how it should be rendered
    */
    public function musicnight_print_element( $atts, $content = null ) {
		extract( shortcode_atts( array(        
			'woo_category' => '',
			'woo_tag' => '',
			'woo_style' => '',
			'num_fetch' => '',
			'num_excerpt' => '',
			'orderby' => '',
			'order' => '',
			'pagination' => ''
		), $atts ) );

		$content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content		
		$settings['category'] = $woo_category;
		$settings['tag'] = $woo_tag;
		$settings['woo-column-size'] = $woo_style;
		$settings['num-fetch'] = $num_fetch;
		$settings['num-excerpt'] = $num_excerpt;
		$settings['orderby'] = $orderby;		
		$settings['order'] = $order;
		$settings['pagination'] = $pagination;
		$output = '<div class="row">'.musicnight_get_woo_item($settings).'</div>';
		return $output;
    }
    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    public function musicnight_load_style() {
      // wp_register_style( 'vc_extend_style', plugins_url('assets/vc_extend.css', __FILE__) );
      // wp_enqueue_style( 'vc_extend_style' );
      // If you need any javascript files on front end, here is how you can load them.
      //wp_enqueue_script( 'vc_extend_js', plugins_url('assets/vc_extend.js', __FILE__), array('jquery') );
    }
    /*
    Show notice if your plugin is activated but Visual Composer is not
    */
    public function musicnight_print_vc_notice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'music-night'), $plugin_data['Name']).'</p>
        </div>';
    }
}
// Finally initialize code
new musicnight_extend_vc_addon_woo();