<?php
// don't load directly
if (!defined('ABSPATH')) die('-1');

class bethany_extend_vc_addon_video {
    function __construct() {
        // We safely integrate with VC with this hook
        add_action( 'init', array( $this, 'bethany_vc_notice' ) );
 
        // Use this when creating a shortcode addon
        add_shortcode( 'video_item', array( $this, 'bethany_print_element' ) );
        // Register CSS and JS
        add_action( 'wp_enqueue_scripts', array( $this, 'bethany_load_style' ) );
    }
 
    public function bethany_vc_notice() {
        // Check if Visual Composer is installed
        if ( ! defined( 'WPB_VC_VERSION' ) ) {
            // Display notice that Visual Compser is required
            // add_action('admin_notices', array( $this, 'bethany_print_vc_notice' ));
            return;
        }
 
        /*
        Add your Visual Composer logic here.
        Lets call vc_map function to "register" our custom shortcode within Visual Composer interface.
        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
        vc_map( array(
            "name" => __("Video Item", 'music-night'),
            //"description" => __("Fetch all the campaign posts from by category or tags.", 'music-night'),
			"description" => __("KodeForest", 'music-night'),
            "base" => "video_item",
            "class" => "",
            "controls" => "full",
            "icon" => "call-to-action", // New param added
            "category" => __('music-night', 'music-night'),
            //'admin_enqueue_js' => array(plugins_url('assets/vc_extend.js', __FILE__)), // This will load js file in the VC backend editor
            'admin_enqueue_css' => array(plugins_url('assets/vc_style_extend.css', __FILE__)), // This will load css file in the VC backend editor
            "params" => array(
				array(
					'type' => 'checkbox',
					'heading' => __( 'Select Category', 'music-night' ),
					'param_name' => 'category',
					'value' => bethany_get_term_list_emptyfirst('video_category'),
					'description' => __( 'Select Category.', 'music-night' )
				),
				array(
					'type' => 'checkbox',
					'heading' => __( 'Select Tag', 'music-night' ),
					'param_name' => 'tag',
					'value' => bethany_get_term_list_emptyfirst('video_tag'),
					'description' => __( 'Select Tag.', 'music-night' )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Select Style', 'music-night' ),
					'param_name' => 'video_style',
					'value' => array(
					    __( ' ', 'music-night' ) => 'no-category',
						__( 'Normal View', 'music-night' ) => 'normal-view',
					),
					'description' => __( 'Select Style.', 'music-night' )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Select Thumbnail Size', 'music-night' ),
					'param_name' => 'thumbnail_size',
					'value' => bethany_get_thumbnail_list_emptyfirst(),
					'description' => __( 'Select Image Size from here.', 'music-night' )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Select Column', 'music-night' ),
					'param_name' => 'video_column',
					'value' => array(
					    __( ' ', 'music-night' ) => 'no-category',
						__( '2 Column', 'music-night' ) => '2',
						__( '3 Column', 'music-night' ) => '3',
						__( '4 Column', 'music-night' ) => '4',
					),
					'description' => __( 'Select Style.', 'music-night' )
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Num Fetch", 'music-night'),
					"param_name" => "num_fetch",
					"value" => __(" ", 'music-night'),
					"description" => __("Specify the number of campaign you want to pull out.", 'music-night')
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Num Excerpt", 'music-night'),
					"param_name" => "num_excerpt",
					"value" => __(" ", 'music-night'),
					"description" => __("Specify the number of discriprion words you want to pull out.", 'music-night')
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Title Num Fetch", 'music-night'),
					"param_name" => "title_num_excerpt",
					"value" => __("", 'music-night'),
					"description" => __("Specify the number of title characters you want to pull out.", 'music-night')
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Order By', 'music-night' ),
					'param_name' => 'orderby',
					'value' => array(
					    __( ' ', 'music-night' ) => 'no-category',
						__( 'Publish Date', 'music-night' ) => 'date',
						__( 'Title', 'music-night' ) => 'title',
						__( 'Random', 'music-night' ) => 'rand',
					),				
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Order', 'music-night' ),
					'param_name' => 'order',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Descending Order', 'music-night' ) => 'desc',
						__( 'Ascending Order', 'music-night' ) => 'asc'						
					),				
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Pagination', 'music-night' ),
					'param_name' => 'pagination',
					'value' => array(
						__( ' ', 'music-night' ) => 'no-category',
						__( 'Enable', 'music-night' ) => 'enable',
						__( 'Disable', 'music-night' ) => 'disable'						
					),				
				),
				array(
					"type" => "textfield",
					"class" => "",
					"heading" => __("Margin Bottom", 'music-night'),
					"param_name" => "margin_bottom",
					"value" => __(" ", 'music-night'),
					"description" => __("margin from bottom without pixel for example : 10.", 'music-night')
				),
            )
        ) );
    }
	
	
    
    /*
    Shortcode logic how it should be rendered
    */
    public function bethany_print_element( $atts, $content = null ) {
		extract( shortcode_atts( array(
			'category' => '',
			'tag' => '',
			'video_style' => '',
			'thumbnail_size' => '',
			'video_column' => '',
			'num_fetch' => '',
			'num_excerpt' => '',
			'title_num_excerpt' => '',
			'orderby' => '',
			'order' => '',
			'pagination' => '',
			'margin_bottom' => '',
		), $atts ) );

		$content = wpb_js_remove_wpautop($content, true); // fix unclosed/unwanted paragraph tags in $content		
		$settings['category'] = $category;
		$settings['tag'] = $tag;
		$settings['video-style'] = $video_style;
		$settings['thumbnail-size'] = $thumbnail_size;
		$settings['video-column'] = $video_column;
		$settings['num-fetch'] = $num_fetch;
		$settings['num-excerpt'] = $num_excerpt;
		$settings['title-num-excerpt'] = $title_num_excerpt;
		$settings['orderby'] = $orderby;		
		$settings['order'] = $order;
		$settings['pagination'] = $pagination;
		$settings['margin-bottom'] = $margin_bottom;
		
		$output = '<div class="row">'.bethany_get_video_item($settings).'</div>';
		return $output;
    }
    /*
    Load plugin css and javascript files which you may need on front end of your site
    */
    public function bethany_load_style() {
		
    }
    /*
    Show notice if your plugin is activated but Visual Composer is not
    */
    public function bethany_print_vc_notice() {
        $plugin_data = get_plugin_data(__FILE__);
        echo '
        <div class="updated">
          <p>'.sprintf(__('<strong>%s</strong> requires <strong><a href="http://bit.ly/vcomposer" target="_blank">Visual Composer</a></strong> plugin to be installed and activated on your site.', 'music-night'), $plugin_data['Name']).'</p>
        </div>';
    }
}
// Finally initialize code
new bethany_extend_vc_addon_video();